/**
 * (C) Copyright IBM Corp. 2023.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
/// <reference types="node" />
/// <reference types="node" />
import { IncomingHttpHeaders, OutgoingHttpHeaders } from 'http';
import { BaseService, UserOptions } from 'ibm-cloud-sdk-core';
/**
 * No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)
 *
 * API Version: 1.0
 */
declare class EventNotificationsV1 extends BaseService {
    static DEFAULT_SERVICE_URL: string;
    static DEFAULT_SERVICE_NAME: string;
    /*************************
     * Factory method
     ************************/
    /**
     * Constructs an instance of EventNotificationsV1 with passed in options and external configuration.
     *
     * @param {UserOptions} [options] - The parameters to send to the service.
     * @param {string} [options.serviceName] - The name of the service to configure
     * @param {Authenticator} [options.authenticator] - The Authenticator object used to authenticate requests to the service
     * @param {string} [options.serviceUrl] - The URL for the service
     * @returns {EventNotificationsV1}
     */
    static newInstance(options: UserOptions): EventNotificationsV1;
    /**
     * Construct a EventNotificationsV1 object.
     *
     * @param {Object} options - Options for the service.
     * @param {string} [options.serviceUrl] - The base url to use when contacting the service. The base url may differ between IBM Cloud regions.
     * @param {OutgoingHttpHeaders} [options.headers] - Default headers that shall be included with every request to the service.
     * @param {Authenticator} options.authenticator - The Authenticator object used to authenticate requests to the service
     * @constructor
     * @returns {EventNotificationsV1}
     */
    constructor(options: UserOptions);
    /*************************
     * sendNotifications
     ************************/
    /**
     * Send a notification.
     *
     * Send Notifications body from the instance. For more information about Event Notifications payload, see
     * [here](https://cloud.ibm.com/docs/event-notifications?topic=event-notifications-en-spec-payload).
     *
     * @param {Object} params - The parameters to send to the service.
     * @param {string} params.instanceId - Unique identifier for IBM Cloud Event Notifications instance.
     * @param {NotificationCreate} [params.body] -
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<EventNotificationsV1.Response<EventNotificationsV1.NotificationResponse>>}
     */
    sendNotifications(params: EventNotificationsV1.SendNotificationsParams): Promise<EventNotificationsV1.Response<EventNotificationsV1.NotificationResponse>>;
    /**
     * Send Bulk notification.
     *
     * @param {Object} params - The parameters to send to the service.
     * @param {string} params.instanceId - Unique identifier for IBM Cloud Event Notifications instance.
     * @param {NotificationCreate[]} [params.bulkMessages] - List of notifications body.
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<EventNotificationsV1.Response<EventNotificationsV1.BulkNotificationResponse>>}
     */
    sendBulkNotifications(params: EventNotificationsV1.SendBulkNotificationsParams): Promise<EventNotificationsV1.Response<EventNotificationsV1.BulkNotificationResponse>>;
    /*************************
     * sources
     ************************/
    /**
     * Create a new API Source.
     *
     * Create a new API Source.
     *
     * @param {Object} params - The parameters to send to the service.
     * @param {string} params.instanceId - Unique identifier for IBM Cloud Event Notifications instance.
     * @param {string} params.name - Name of the source.
     * @param {string} params.description - Description of the source.
     * @param {boolean} [params.enabled] - Whether the source is enabled or not.
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<EventNotificationsV1.Response<EventNotificationsV1.SourceResponse>>}
     */
    createSources(params: EventNotificationsV1.CreateSourcesParams): Promise<EventNotificationsV1.Response<EventNotificationsV1.SourceResponse>>;
    /**
     * List all Sources.
     *
     * List all Sources.
     *
     * @param {Object} params - The parameters to send to the service.
     * @param {string} params.instanceId - Unique identifier for IBM Cloud Event Notifications instance.
     * @param {number} [params.limit] - Page limit for paginated results.
     * @param {number} [params.offset] - offset for paginated results.
     * @param {string} [params.search] - Search string for filtering results.
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<EventNotificationsV1.Response<EventNotificationsV1.SourceList>>}
     */
    listSources(params: EventNotificationsV1.ListSourcesParams): Promise<EventNotificationsV1.Response<EventNotificationsV1.SourceList>>;
    /**
     * Get a Source.
     *
     * Get a Source.
     *
     * @param {Object} params - The parameters to send to the service.
     * @param {string} params.instanceId - Unique identifier for IBM Cloud Event Notifications instance.
     * @param {string} params.id - Unique identifier for Source.
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<EventNotificationsV1.Response<EventNotificationsV1.Source>>}
     */
    getSource(params: EventNotificationsV1.GetSourceParams): Promise<EventNotificationsV1.Response<EventNotificationsV1.Source>>;
    /**
     * Delete a Source.
     *
     * Delete a Source.
     *
     * @param {Object} params - The parameters to send to the service.
     * @param {string} params.instanceId - Unique identifier for IBM Cloud Event Notifications instance.
     * @param {string} params.id - Unique identifier for Source.
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<EventNotificationsV1.Response<EventNotificationsV1.Empty>>}
     */
    deleteSource(params: EventNotificationsV1.DeleteSourceParams): Promise<EventNotificationsV1.Response<EventNotificationsV1.Empty>>;
    /**
     * Update details of a Source.
     *
     * Update details of a Source.
     *
     * @param {Object} params - The parameters to send to the service.
     * @param {string} params.instanceId - Unique identifier for IBM Cloud Event Notifications instance.
     * @param {string} params.id - Unique identifier for Source.
     * @param {string} [params.name] - Name of the source.
     * @param {string} [params.description] - Description of the source.
     * @param {boolean} [params.enabled] - Whether the source is enabled or not.
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<EventNotificationsV1.Response<EventNotificationsV1.Source>>}
     */
    updateSource(params: EventNotificationsV1.UpdateSourceParams): Promise<EventNotificationsV1.Response<EventNotificationsV1.Source>>;
    /*************************
     * topics
     ************************/
    /**
     * Create a new Topic.
     *
     * Create a new Topic.
     *
     * @param {Object} params - The parameters to send to the service.
     * @param {string} params.instanceId - Unique identifier for IBM Cloud Event Notifications instance.
     * @param {string} params.name - Name of the topic.
     * @param {string} [params.description] - Description of the topic.
     * @param {SourcesItems[]} [params.sources] - List of sources.
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<EventNotificationsV1.Response<EventNotificationsV1.TopicResponse>>}
     */
    createTopic(params: EventNotificationsV1.CreateTopicParams): Promise<EventNotificationsV1.Response<EventNotificationsV1.TopicResponse>>;
    /**
     * List all Topics.
     *
     * List all Topics.
     *
     * @param {Object} params - The parameters to send to the service.
     * @param {string} params.instanceId - Unique identifier for IBM Cloud Event Notifications instance.
     * @param {number} [params.limit] - Page limit for paginated results.
     * @param {number} [params.offset] - offset for paginated results.
     * @param {string} [params.search] - Search string for filtering results.
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<EventNotificationsV1.Response<EventNotificationsV1.TopicList>>}
     */
    listTopics(params: EventNotificationsV1.ListTopicsParams): Promise<EventNotificationsV1.Response<EventNotificationsV1.TopicList>>;
    /**
     * Get details of a Topic.
     *
     * Get details of a Topic.
     *
     * @param {Object} params - The parameters to send to the service.
     * @param {string} params.instanceId - Unique identifier for IBM Cloud Event Notifications instance.
     * @param {string} params.id - Unique identifier for Topic.
     * @param {string} [params.include] - Include sub topics.
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<EventNotificationsV1.Response<EventNotificationsV1.Topic>>}
     */
    getTopic(params: EventNotificationsV1.GetTopicParams): Promise<EventNotificationsV1.Response<EventNotificationsV1.Topic>>;
    /**
     * Update details of a Topic.
     *
     * Update details of a Topic.
     *
     * @param {Object} params - The parameters to send to the service.
     * @param {string} params.instanceId - Unique identifier for IBM Cloud Event Notifications instance.
     * @param {string} params.id - Unique identifier for Topic.
     * @param {string} [params.name] - Name of the topic.
     * @param {string} [params.description] - Description of the topic.
     * @param {SourcesItems[]} [params.sources] - List of sources.
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<EventNotificationsV1.Response<EventNotificationsV1.Topic>>}
     */
    replaceTopic(params: EventNotificationsV1.ReplaceTopicParams): Promise<EventNotificationsV1.Response<EventNotificationsV1.Topic>>;
    /**
     * Delete a Topic.
     *
     * Delete a Topic.
     *
     * @param {Object} params - The parameters to send to the service.
     * @param {string} params.instanceId - Unique identifier for IBM Cloud Event Notifications instance.
     * @param {string} params.id - Unique identifier for Topic.
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<EventNotificationsV1.Response<EventNotificationsV1.Empty>>}
     */
    deleteTopic(params: EventNotificationsV1.DeleteTopicParams): Promise<EventNotificationsV1.Response<EventNotificationsV1.Empty>>;
    /*************************
     * destinations
     ************************/
    /**
     * Create a new Destination.
     *
     * Create a new Destination.
     *
     * @param {Object} params - The parameters to send to the service.
     * @param {string} params.instanceId - Unique identifier for IBM Cloud Event Notifications instance.
     * @param {string} params.name - The Destination name.
     * @param {string} params.type - The type of Destination Webhook.
     * @param {string} [params.description] - The Destination description.
     * @param {DestinationConfig} [params.config] - Payload describing a destination configuration.
     * @param {NodeJS.ReadableStream | Buffer} [params.certificate] - Certificate for APNS.
     * @param {string} [params.certificateContentType] - The content type of certificate.
     * @param {NodeJS.ReadableStream | Buffer} [params.icon16x16] - Safari icon 16x16.
     * @param {string} [params.icon16x16ContentType] - The content type of icon16x16.
     * @param {NodeJS.ReadableStream | Buffer} [params.icon16x162x] - Safari icon 16x16@2x.
     * @param {string} [params.icon16x162xContentType] - The content type of icon16x162x.
     * @param {NodeJS.ReadableStream | Buffer} [params.icon32x32] - Safari icon 32x32.
     * @param {string} [params.icon32x32ContentType] - The content type of icon32x32.
     * @param {NodeJS.ReadableStream | Buffer} [params.icon32x322x] - Safari icon 32x32@2x.
     * @param {string} [params.icon32x322xContentType] - The content type of icon32x322x.
     * @param {NodeJS.ReadableStream | Buffer} [params.icon128x128] - Safari icon 128x128.
     * @param {string} [params.icon128x128ContentType] - The content type of icon128x128.
     * @param {NodeJS.ReadableStream | Buffer} [params.icon128x1282x] - Safari icon 128x128@2x.
     * @param {string} [params.icon128x1282xContentType] - The content type of icon128x1282x.
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<EventNotificationsV1.Response<EventNotificationsV1.DestinationResponse>>}
     */
    createDestination(params: EventNotificationsV1.CreateDestinationParams): Promise<EventNotificationsV1.Response<EventNotificationsV1.DestinationResponse>>;
    /**
     * List all Destinations.
     *
     * List all Destinations.
     *
     * @param {Object} params - The parameters to send to the service.
     * @param {string} params.instanceId - Unique identifier for IBM Cloud Event Notifications instance.
     * @param {number} [params.limit] - Page limit for paginated results.
     * @param {number} [params.offset] - offset for paginated results.
     * @param {string} [params.search] - Search string for filtering results.
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<EventNotificationsV1.Response<EventNotificationsV1.DestinationList>>}
     */
    listDestinations(params: EventNotificationsV1.ListDestinationsParams): Promise<EventNotificationsV1.Response<EventNotificationsV1.DestinationList>>;
    /**
     * Get details of a Destination.
     *
     * Get details of a Destination.
     *
     * @param {Object} params - The parameters to send to the service.
     * @param {string} params.instanceId - Unique identifier for IBM Cloud Event Notifications instance.
     * @param {string} params.id - Unique identifier for Destination.
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<EventNotificationsV1.Response<EventNotificationsV1.Destination>>}
     */
    getDestination(params: EventNotificationsV1.GetDestinationParams): Promise<EventNotificationsV1.Response<EventNotificationsV1.Destination>>;
    /**
     * Update details of a Destination.
     *
     * Update details of a Destination.
     *
     * @param {Object} params - The parameters to send to the service.
     * @param {string} params.instanceId - Unique identifier for IBM Cloud Event Notifications instance.
     * @param {string} params.id - Unique identifier for Destination.
     * @param {string} [params.name] - Destination name.
     * @param {string} [params.description] - Destination description.
     * @param {DestinationConfig} [params.config] - Payload describing a destination configuration.
     * @param {NodeJS.ReadableStream | Buffer} [params.certificate] - Certificate for APNS.
     * @param {string} [params.certificateContentType] - The content type of certificate.
     * @param {NodeJS.ReadableStream | Buffer} [params.icon16x16] - Safari icon 16x16.
     * @param {string} [params.icon16x16ContentType] - The content type of icon16x16.
     * @param {NodeJS.ReadableStream | Buffer} [params.icon16x162x] - Safari icon 16x16@2x.
     * @param {string} [params.icon16x162xContentType] - The content type of icon16x162x.
     * @param {NodeJS.ReadableStream | Buffer} [params.icon32x32] - Safari icon 32x32.
     * @param {string} [params.icon32x32ContentType] - The content type of icon32x32.
     * @param {NodeJS.ReadableStream | Buffer} [params.icon32x322x] - Safari icon 32x32@2x.
     * @param {string} [params.icon32x322xContentType] - The content type of icon32x322x.
     * @param {NodeJS.ReadableStream | Buffer} [params.icon128x128] - Safari icon 128x128.
     * @param {string} [params.icon128x128ContentType] - The content type of icon128x128.
     * @param {NodeJS.ReadableStream | Buffer} [params.icon128x1282x] - Safari icon 128x128@2x.
     * @param {string} [params.icon128x1282xContentType] - The content type of icon128x1282x.
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<EventNotificationsV1.Response<EventNotificationsV1.Destination>>}
     */
    updateDestination(params: EventNotificationsV1.UpdateDestinationParams): Promise<EventNotificationsV1.Response<EventNotificationsV1.Destination>>;
    /**
     * Delete a Destination.
     *
     * Delete a Destination.
     *
     * @param {Object} params - The parameters to send to the service.
     * @param {string} params.instanceId - Unique identifier for IBM Cloud Event Notifications instance.
     * @param {string} params.id - Unique identifier for Destination.
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<EventNotificationsV1.Response<EventNotificationsV1.Empty>>}
     */
    deleteDestination(params: EventNotificationsV1.DeleteDestinationParams): Promise<EventNotificationsV1.Response<EventNotificationsV1.Empty>>;
    /*************************
     * pushDestinationAPIs
     ************************/
    /**
     * Create a new tag subscription.
     *
     * Create a new tag subscription.
     *
     * @param {Object} params - The parameters to send to the service.
     * @param {string} params.instanceId - Unique identifier for IBM Cloud Event Notifications instance.
     * @param {string} params.id - Unique identifier for Destination.
     * @param {string} params.deviceId - Unique identifier of the device.
     * @param {string} params.tagName - The name of the tag its subscribed.
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<EventNotificationsV1.Response<EventNotificationsV1.DestinationTagsSubscriptionResponse>>}
     */
    createTagsSubscription(params: EventNotificationsV1.CreateTagsSubscriptionParams): Promise<EventNotificationsV1.Response<EventNotificationsV1.DestinationTagsSubscriptionResponse>>;
    /**
     * List all tag subscriptions.
     *
     * List all tag subscriptions.
     *
     * @param {Object} params - The parameters to send to the service.
     * @param {string} params.instanceId - Unique identifier for IBM Cloud Event Notifications instance.
     * @param {string} params.id - Unique identifier for Destination.
     * @param {string} [params.deviceId] - Device ID of the destination tagsubscription.
     * @param {string} [params.userId] - UserID of the destination.
     * @param {string} [params.tagName] - TagName of the subscription.
     * @param {number} [params.limit] - Page limit for paginated results.
     * @param {number} [params.offset] - offset for paginated results.
     * @param {string} [params.search] - Search string for filtering results.
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<EventNotificationsV1.Response<EventNotificationsV1.TagsSubscriptionList>>}
     */
    listTagsSubscription(params: EventNotificationsV1.ListTagsSubscriptionParams): Promise<EventNotificationsV1.Response<EventNotificationsV1.TagsSubscriptionList>>;
    /**
     * Delete a tag subscription.
     *
     * Delete a tag subscription.
     *
     * @param {Object} params - The parameters to send to the service.
     * @param {string} params.instanceId - Unique identifier for IBM Cloud Event Notifications instance.
     * @param {string} params.id - Unique identifier for Destination.
     * @param {string} [params.deviceId] - Device ID of the destination tagsubscription.
     * @param {string} [params.tagName] - TagName of the subscription.
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<EventNotificationsV1.Response<EventNotificationsV1.Empty>>}
     */
    deleteTagsSubscription(params: EventNotificationsV1.DeleteTagsSubscriptionParams): Promise<EventNotificationsV1.Response<EventNotificationsV1.Empty>>;
    /*************************
     * subscriptions
     ************************/
    /**
     * Create a new Subscription.
     *
     * Create a new Subscription.
     *
     * @param {Object} params - The parameters to send to the service.
     * @param {string} params.instanceId - Unique identifier for IBM Cloud Event Notifications instance.
     * @param {string} params.name - Subscription name.
     * @param {string} params.destinationId - Destination ID.
     * @param {string} params.topicId - Topic ID.
     * @param {string} [params.description] - Subscription description.
     * @param {SubscriptionCreateAttributes} [params.attributes] -
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<EventNotificationsV1.Response<EventNotificationsV1.Subscription>>}
     */
    createSubscription(params: EventNotificationsV1.CreateSubscriptionParams): Promise<EventNotificationsV1.Response<EventNotificationsV1.Subscription>>;
    /**
     * List all Subscriptions.
     *
     * List all Subscriptions.
     *
     * @param {Object} params - The parameters to send to the service.
     * @param {string} params.instanceId - Unique identifier for IBM Cloud Event Notifications instance.
     * @param {number} [params.offset] - offset for paginated results.
     * @param {number} [params.limit] - Page limit for paginated results.
     * @param {string} [params.search] - Search string for filtering results.
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<EventNotificationsV1.Response<EventNotificationsV1.SubscriptionList>>}
     */
    listSubscriptions(params: EventNotificationsV1.ListSubscriptionsParams): Promise<EventNotificationsV1.Response<EventNotificationsV1.SubscriptionList>>;
    /**
     * Get details of a Subscription.
     *
     * Get details of a Subscription.
     *
     * @param {Object} params - The parameters to send to the service.
     * @param {string} params.instanceId - Unique identifier for IBM Cloud Event Notifications instance.
     * @param {string} params.id - Unique identifier for Subscription.
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<EventNotificationsV1.Response<EventNotificationsV1.Subscription>>}
     */
    getSubscription(params: EventNotificationsV1.GetSubscriptionParams): Promise<EventNotificationsV1.Response<EventNotificationsV1.Subscription>>;
    /**
     * Delete a Subscription.
     *
     * Delete a Subscription.
     *
     * @param {Object} params - The parameters to send to the service.
     * @param {string} params.instanceId - Unique identifier for IBM Cloud Event Notifications instance.
     * @param {string} params.id - Unique identifier for Subscription.
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<EventNotificationsV1.Response<EventNotificationsV1.Empty>>}
     */
    deleteSubscription(params: EventNotificationsV1.DeleteSubscriptionParams): Promise<EventNotificationsV1.Response<EventNotificationsV1.Empty>>;
    /**
     * Update details of a Subscription.
     *
     * Update details of a Subscription.
     *
     * @param {Object} params - The parameters to send to the service.
     * @param {string} params.instanceId - Unique identifier for IBM Cloud Event Notifications instance.
     * @param {string} params.id - Unique identifier for Subscription.
     * @param {string} [params.name] - Name of the subscription.
     * @param {string} [params.description] - Description of the subscription.
     * @param {SubscriptionUpdateAttributes} [params.attributes] -
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<EventNotificationsV1.Response<EventNotificationsV1.Subscription>>}
     */
    updateSubscription(params: EventNotificationsV1.UpdateSubscriptionParams): Promise<EventNotificationsV1.Response<EventNotificationsV1.Subscription>>;
    /*************************
     * kMSIntegrations
     ************************/
    /**
     * List all Integrations.
     *
     * List of all KMS Integrations.
     *
     * @param {Object} params - The parameters to send to the service.
     * @param {string} params.instanceId - Unique identifier for IBM Cloud Event Notifications instance.
     * @param {number} [params.offset] - offset for paginated results.
     * @param {number} [params.limit] - Page limit for paginated results.
     * @param {string} [params.search] - Search string for filtering results.
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<EventNotificationsV1.Response<EventNotificationsV1.IntegrationList>>}
     */
    listIntegrations(params: EventNotificationsV1.ListIntegrationsParams): Promise<EventNotificationsV1.Response<EventNotificationsV1.IntegrationList>>;
    /**
     * Get a single Integration.
     *
     * Get a single KMS Integration.
     *
     * @param {Object} params - The parameters to send to the service.
     * @param {string} params.instanceId - Unique identifier for IBM Cloud Event Notifications instance.
     * @param {string} params.id - Unique identifier for integration.
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<EventNotificationsV1.Response<EventNotificationsV1.IntegrationGetResponse>>}
     */
    getIntegration(params: EventNotificationsV1.GetIntegrationParams): Promise<EventNotificationsV1.Response<EventNotificationsV1.IntegrationGetResponse>>;
    /**
     * Update an existing Integration.
     *
     * Update an existing KMS Integration.
     *
     * @param {Object} params - The parameters to send to the service.
     * @param {string} params.instanceId - Unique identifier for IBM Cloud Event Notifications instance.
     * @param {string} params.id - Unique identifier for integration.
     * @param {string} params.type - Integration type. Allowed values are kms and hs-crypto.
     * @param {IntegrationMetadata} params.metadata - Integration Metadata object.
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<EventNotificationsV1.Response<EventNotificationsV1.IntegrationGetResponse>>}
     */
    replaceIntegration(params: EventNotificationsV1.ReplaceIntegrationParams): Promise<EventNotificationsV1.Response<EventNotificationsV1.IntegrationGetResponse>>;
}
/*************************
 * interfaces
 ************************/
declare namespace EventNotificationsV1 {
    /** An operation response. */
    interface Response<T = any> {
        result: T;
        status: number;
        statusText: string;
        headers: IncomingHttpHeaders;
    }
    /** The callback for a service request. */
    type Callback<T> = (error: any, response?: Response<T>) => void;
    /** The body of a service request that returns no response data. */
    interface Empty {
    }
    /** A standard JS object, defined to avoid the limitations of `Object` and `object` */
    interface JsonObject {
        [key: string]: any;
    }
    /*************************
     * request interfaces
     ************************/
    /** Parameters for the `sendNotifications` operation. */
    interface SendNotificationsParams {
        /** Unique identifier for IBM Cloud Event Notifications instance. */
        instanceId: string;
        body?: NotificationCreate;
        headers?: OutgoingHttpHeaders;
    }
    /** Parameters for the `sendBulkNotifications` operation. */
    interface SendBulkNotificationsParams {
        /** Unique identifier for IBM Cloud Event Notifications instance. */
        instanceId: string;
        /** List of notifications body. */
        bulkMessages?: NotificationCreate[];
        headers?: OutgoingHttpHeaders;
    }
    /** Parameters for the `createSources` operation. */
    interface CreateSourcesParams {
        /** Unique identifier for IBM Cloud Event Notifications instance. */
        instanceId: string;
        /** Name of the source. */
        name: string;
        /** Description of the source. */
        description: string;
        /** Whether the source is enabled or not. */
        enabled?: boolean;
        headers?: OutgoingHttpHeaders;
    }
    /** Parameters for the `listSources` operation. */
    interface ListSourcesParams {
        /** Unique identifier for IBM Cloud Event Notifications instance. */
        instanceId: string;
        /** Page limit for paginated results. */
        limit?: number;
        /** offset for paginated results. */
        offset?: number;
        /** Search string for filtering results. */
        search?: string;
        headers?: OutgoingHttpHeaders;
    }
    /** Parameters for the `getSource` operation. */
    interface GetSourceParams {
        /** Unique identifier for IBM Cloud Event Notifications instance. */
        instanceId: string;
        /** Unique identifier for Source. */
        id: string;
        headers?: OutgoingHttpHeaders;
    }
    /** Parameters for the `deleteSource` operation. */
    interface DeleteSourceParams {
        /** Unique identifier for IBM Cloud Event Notifications instance. */
        instanceId: string;
        /** Unique identifier for Source. */
        id: string;
        headers?: OutgoingHttpHeaders;
    }
    /** Parameters for the `updateSource` operation. */
    interface UpdateSourceParams {
        /** Unique identifier for IBM Cloud Event Notifications instance. */
        instanceId: string;
        /** Unique identifier for Source. */
        id: string;
        /** Name of the source. */
        name?: string;
        /** Description of the source. */
        description?: string;
        /** Whether the source is enabled or not. */
        enabled?: boolean;
        headers?: OutgoingHttpHeaders;
    }
    /** Parameters for the `createTopic` operation. */
    interface CreateTopicParams {
        /** Unique identifier for IBM Cloud Event Notifications instance. */
        instanceId: string;
        /** Name of the topic. */
        name: string;
        /** Description of the topic. */
        description?: string;
        /** List of sources. */
        sources?: SourcesItems[];
        headers?: OutgoingHttpHeaders;
    }
    /** Parameters for the `listTopics` operation. */
    interface ListTopicsParams {
        /** Unique identifier for IBM Cloud Event Notifications instance. */
        instanceId: string;
        /** Page limit for paginated results. */
        limit?: number;
        /** offset for paginated results. */
        offset?: number;
        /** Search string for filtering results. */
        search?: string;
        headers?: OutgoingHttpHeaders;
    }
    /** Parameters for the `getTopic` operation. */
    interface GetTopicParams {
        /** Unique identifier for IBM Cloud Event Notifications instance. */
        instanceId: string;
        /** Unique identifier for Topic. */
        id: string;
        /** Include sub topics. */
        include?: string;
        headers?: OutgoingHttpHeaders;
    }
    /** Parameters for the `replaceTopic` operation. */
    interface ReplaceTopicParams {
        /** Unique identifier for IBM Cloud Event Notifications instance. */
        instanceId: string;
        /** Unique identifier for Topic. */
        id: string;
        /** Name of the topic. */
        name?: string;
        /** Description of the topic. */
        description?: string;
        /** List of sources. */
        sources?: SourcesItems[];
        headers?: OutgoingHttpHeaders;
    }
    /** Parameters for the `deleteTopic` operation. */
    interface DeleteTopicParams {
        /** Unique identifier for IBM Cloud Event Notifications instance. */
        instanceId: string;
        /** Unique identifier for Topic. */
        id: string;
        headers?: OutgoingHttpHeaders;
    }
    /** Parameters for the `createDestination` operation. */
    interface CreateDestinationParams {
        /** Unique identifier for IBM Cloud Event Notifications instance. */
        instanceId: string;
        /** The Destination name. */
        name: string;
        /** The type of Destination Webhook. */
        type: CreateDestinationConstants.Type | string;
        /** The Destination description. */
        description?: string;
        /** Payload describing a destination configuration. */
        config?: DestinationConfig;
        /** Certificate for APNS. */
        certificate?: NodeJS.ReadableStream | Buffer;
        /** The content type of certificate. */
        certificateContentType?: string;
        /** Safari icon 16x16. */
        icon16x16?: NodeJS.ReadableStream | Buffer;
        /** The content type of icon16x16. */
        icon16x16ContentType?: string;
        /** Safari icon 16x16@2x. */
        icon16x162x?: NodeJS.ReadableStream | Buffer;
        /** The content type of icon16x162x. */
        icon16x162xContentType?: string;
        /** Safari icon 32x32. */
        icon32x32?: NodeJS.ReadableStream | Buffer;
        /** The content type of icon32x32. */
        icon32x32ContentType?: string;
        /** Safari icon 32x32@2x. */
        icon32x322x?: NodeJS.ReadableStream | Buffer;
        /** The content type of icon32x322x. */
        icon32x322xContentType?: string;
        /** Safari icon 128x128. */
        icon128x128?: NodeJS.ReadableStream | Buffer;
        /** The content type of icon128x128. */
        icon128x128ContentType?: string;
        /** Safari icon 128x128@2x. */
        icon128x1282x?: NodeJS.ReadableStream | Buffer;
        /** The content type of icon128x1282x. */
        icon128x1282xContentType?: string;
        headers?: OutgoingHttpHeaders;
    }
    /** Constants for the `createDestination` operation. */
    namespace CreateDestinationConstants {
        /** The type of Destination Webhook. */
        enum Type {
            WEBHOOK = "webhook",
            PUSH_ANDROID = "push_android",
            PUSH_IOS = "push_ios",
            PUSH_CHROME = "push_chrome",
            PUSH_FIREFOX = "push_firefox",
            SLACK = "slack",
            IBMCF = "ibmcf",
            IBMCE = "ibmce",
            PAGERDUTY = "pagerduty",
            PUSH_SAFARI = "push_safari",
            MSTEAMS = "msteams",
            SERVICENOW = "servicenow"
        }
    }
    /** Parameters for the `listDestinations` operation. */
    interface ListDestinationsParams {
        /** Unique identifier for IBM Cloud Event Notifications instance. */
        instanceId: string;
        /** Page limit for paginated results. */
        limit?: number;
        /** offset for paginated results. */
        offset?: number;
        /** Search string for filtering results. */
        search?: string;
        headers?: OutgoingHttpHeaders;
    }
    /** Parameters for the `getDestination` operation. */
    interface GetDestinationParams {
        /** Unique identifier for IBM Cloud Event Notifications instance. */
        instanceId: string;
        /** Unique identifier for Destination. */
        id: string;
        headers?: OutgoingHttpHeaders;
    }
    /** Parameters for the `updateDestination` operation. */
    interface UpdateDestinationParams {
        /** Unique identifier for IBM Cloud Event Notifications instance. */
        instanceId: string;
        /** Unique identifier for Destination. */
        id: string;
        /** Destination name. */
        name?: string;
        /** Destination description. */
        description?: string;
        /** Payload describing a destination configuration. */
        config?: DestinationConfig;
        /** Certificate for APNS. */
        certificate?: NodeJS.ReadableStream | Buffer;
        /** The content type of certificate. */
        certificateContentType?: string;
        /** Safari icon 16x16. */
        icon16x16?: NodeJS.ReadableStream | Buffer;
        /** The content type of icon16x16. */
        icon16x16ContentType?: string;
        /** Safari icon 16x16@2x. */
        icon16x162x?: NodeJS.ReadableStream | Buffer;
        /** The content type of icon16x162x. */
        icon16x162xContentType?: string;
        /** Safari icon 32x32. */
        icon32x32?: NodeJS.ReadableStream | Buffer;
        /** The content type of icon32x32. */
        icon32x32ContentType?: string;
        /** Safari icon 32x32@2x. */
        icon32x322x?: NodeJS.ReadableStream | Buffer;
        /** The content type of icon32x322x. */
        icon32x322xContentType?: string;
        /** Safari icon 128x128. */
        icon128x128?: NodeJS.ReadableStream | Buffer;
        /** The content type of icon128x128. */
        icon128x128ContentType?: string;
        /** Safari icon 128x128@2x. */
        icon128x1282x?: NodeJS.ReadableStream | Buffer;
        /** The content type of icon128x1282x. */
        icon128x1282xContentType?: string;
        headers?: OutgoingHttpHeaders;
    }
    /** Parameters for the `deleteDestination` operation. */
    interface DeleteDestinationParams {
        /** Unique identifier for IBM Cloud Event Notifications instance. */
        instanceId: string;
        /** Unique identifier for Destination. */
        id: string;
        headers?: OutgoingHttpHeaders;
    }
    /** Parameters for the `createTagsSubscription` operation. */
    interface CreateTagsSubscriptionParams {
        /** Unique identifier for IBM Cloud Event Notifications instance. */
        instanceId: string;
        /** Unique identifier for Destination. */
        id: string;
        /** Unique identifier of the device. */
        deviceId: string;
        /** The name of the tag its subscribed. */
        tagName: string;
        headers?: OutgoingHttpHeaders;
    }
    /** Parameters for the `listTagsSubscription` operation. */
    interface ListTagsSubscriptionParams {
        /** Unique identifier for IBM Cloud Event Notifications instance. */
        instanceId: string;
        /** Unique identifier for Destination. */
        id: string;
        /** Device ID of the destination tagsubscription. */
        deviceId?: string;
        /** UserID of the destination. */
        userId?: string;
        /** TagName of the subscription. */
        tagName?: string;
        /** Page limit for paginated results. */
        limit?: number;
        /** offset for paginated results. */
        offset?: number;
        /** Search string for filtering results. */
        search?: string;
        headers?: OutgoingHttpHeaders;
    }
    /** Parameters for the `deleteTagsSubscription` operation. */
    interface DeleteTagsSubscriptionParams {
        /** Unique identifier for IBM Cloud Event Notifications instance. */
        instanceId: string;
        /** Unique identifier for Destination. */
        id: string;
        /** Device ID of the destination tagsubscription. */
        deviceId?: string;
        /** TagName of the subscription. */
        tagName?: string;
        headers?: OutgoingHttpHeaders;
    }
    /** Parameters for the `createSubscription` operation. */
    interface CreateSubscriptionParams {
        /** Unique identifier for IBM Cloud Event Notifications instance. */
        instanceId: string;
        /** Subscription name. */
        name: string;
        /** Destination ID. */
        destinationId: string;
        /** Topic ID. */
        topicId: string;
        /** Subscription description. */
        description?: string;
        attributes?: SubscriptionCreateAttributes;
        headers?: OutgoingHttpHeaders;
    }
    /** Parameters for the `listSubscriptions` operation. */
    interface ListSubscriptionsParams {
        /** Unique identifier for IBM Cloud Event Notifications instance. */
        instanceId: string;
        /** offset for paginated results. */
        offset?: number;
        /** Page limit for paginated results. */
        limit?: number;
        /** Search string for filtering results. */
        search?: string;
        headers?: OutgoingHttpHeaders;
    }
    /** Parameters for the `getSubscription` operation. */
    interface GetSubscriptionParams {
        /** Unique identifier for IBM Cloud Event Notifications instance. */
        instanceId: string;
        /** Unique identifier for Subscription. */
        id: string;
        headers?: OutgoingHttpHeaders;
    }
    /** Parameters for the `deleteSubscription` operation. */
    interface DeleteSubscriptionParams {
        /** Unique identifier for IBM Cloud Event Notifications instance. */
        instanceId: string;
        /** Unique identifier for Subscription. */
        id: string;
        headers?: OutgoingHttpHeaders;
    }
    /** Parameters for the `updateSubscription` operation. */
    interface UpdateSubscriptionParams {
        /** Unique identifier for IBM Cloud Event Notifications instance. */
        instanceId: string;
        /** Unique identifier for Subscription. */
        id: string;
        /** Name of the subscription. */
        name?: string;
        /** Description of the subscription. */
        description?: string;
        attributes?: SubscriptionUpdateAttributes;
        headers?: OutgoingHttpHeaders;
    }
    /** Parameters for the `listIntegrations` operation. */
    interface ListIntegrationsParams {
        /** Unique identifier for IBM Cloud Event Notifications instance. */
        instanceId: string;
        /** offset for paginated results. */
        offset?: number;
        /** Page limit for paginated results. */
        limit?: number;
        /** Search string for filtering results. */
        search?: string;
        headers?: OutgoingHttpHeaders;
    }
    /** Parameters for the `getIntegration` operation. */
    interface GetIntegrationParams {
        /** Unique identifier for IBM Cloud Event Notifications instance. */
        instanceId: string;
        /** Unique identifier for integration. */
        id: string;
        headers?: OutgoingHttpHeaders;
    }
    /** Parameters for the `replaceIntegration` operation. */
    interface ReplaceIntegrationParams {
        /** Unique identifier for IBM Cloud Event Notifications instance. */
        instanceId: string;
        /** Unique identifier for integration. */
        id: string;
        /** Integration type. Allowed values are kms and hs-crypto. */
        type: string;
        /** Integration Metadata object. */
        metadata: IntegrationMetadata;
        headers?: OutgoingHttpHeaders;
    }
    /*************************
     * model interfaces
     ************************/
    /** Payload describing a notifications response. */
    interface BulkNotificationResponse {
        /** Bulk Notification ID. */
        bulk_notification_id?: string;
        /** List of Notifications. */
        bulk_messages?: any[];
    }
    /** Payload describing a destination get request. */
    interface Destination {
        /** Destination ID. */
        id: string;
        /** Destination name. */
        name: string;
        /** Destination description. */
        description: string;
        /** Destination type Email/SMS/Webhook/FCM/Slack/MSTeams/PagerDuty/IBMCloudFunctions/IBMCodeEngine/ServiceNow. */
        type: string;
        /** Payload describing a destination configuration. */
        config?: DestinationConfig;
        /** Last updated time. */
        updated_at: string;
        /** Number of subscriptions. */
        subscription_count: number;
        /** List of subscriptions. */
        subscription_names: string[];
    }
    /** Payload describing a destination configuration. */
    interface DestinationConfig {
        params: DestinationConfigOneOf;
    }
    /** DestinationConfigOneOf. */
    interface DestinationConfigOneOf {
    }
    /** Payload describing a destination list request. */
    interface DestinationList {
        /** Total number of destinations. */
        total_count: number;
        /** Current offset. */
        offset: number;
        /** limit to show destinations. */
        limit: number;
        /** List of destinations. */
        destinations: DestinationListItem[];
        /** Response having URL of the page. */
        first?: PageHrefResponse;
        /** Response having URL of the page. */
        previous?: PageHrefResponse;
        /** Response having URL of the page. */
        next?: PageHrefResponse;
    }
    /** Destination object. */
    interface DestinationListItem {
        /** Destination ID. */
        id: string;
        /** Destination name. */
        name: string;
        /** Destination description. */
        description: string;
        /** Destination type. */
        type: string;
        /** Subscription count. */
        subscription_count: number;
        /** Names of subscriptions. */
        subscription_names: string[];
        /** Updated at. */
        updated_at: string;
    }
    /** Payload describing a destination get request. */
    interface DestinationResponse {
        /** Destination ID. */
        id: string;
        /** Destination name. */
        name: string;
        /** Destination description. */
        description: string;
        /** Destination type. */
        type: string;
        /** Payload describing a destination configuration. */
        config: DestinationConfig;
        /** Last updated time. */
        created_at: string;
    }
    /** Payload describing a destination get request. */
    interface DestinationTagsSubscriptionResponse {
        /** Subscription Tag ID. */
        id: string;
        /** Unique identifier of the device. */
        device_id: string;
        /** The name of the tag its subscribed. */
        tag_name: string;
        /** The user identifier for the device registration. */
        user_id?: string;
        /** Last updated time. */
        created_at: string;
    }
    /** EmailAttributesResponseInvitedItems. */
    interface EmailAttributesResponseInvitedItems {
        /** email address. */
        email?: string;
        /** last updated time. */
        updated_at?: string;
        /** time of expiration. */
        expires_at?: string;
    }
    /** EmailAttributesResponseSubscribedUnsubscribedItems. */
    interface EmailAttributesResponseSubscribedUnsubscribedItems {
        /** email address. */
        email?: string;
        /** last updated time. */
        updated_at?: string;
    }
    /** Integration response object. */
    interface IntegrationGetResponse {
        /** ID of the integration. */
        id: string;
        /** Integration type. Allowed values are kms and hs-crypto. */
        type: string;
        /** Integration Metadata object. */
        metadata: IntegrationMetadata;
        /** Creation time of an integration. */
        created_at: string;
        /** Last update time of an integration. */
        updated_at: string;
    }
    /** all Integrations response object. */
    interface IntegrationList {
        /** Number of integrations. */
        total_count: number;
        /** Current offset. */
        offset: number;
        /** limit to show integrations. */
        limit: number;
        /** List of integrations. */
        integrations: IntegrationListItem[];
        /** Response having URL of the page. */
        first?: PageHrefResponse;
        /** Response having URL of the page. */
        previous?: PageHrefResponse;
        /** Response having URL of the page. */
        next?: PageHrefResponse;
    }
    /** all Integrations response object. */
    interface IntegrationListItem {
        /** ID of the integration. */
        id: string;
        /** Integration type. Allowed values are kms and hs-crypto. */
        type: string;
        /** Integration Metadata object. */
        metadata: IntegrationMetadata;
        /** Creation time of an integration. */
        created_at: string;
        /** Update time of an integration. */
        updated_at: string;
    }
    /** Integration Metadata object. */
    interface IntegrationMetadata {
        /** KMS url for key management. */
        endpoint: string;
        /** CRN of the KMS instance. */
        crn: string;
        /** Root Key ID of KMS. */
        root_key_id: string;
    }
    /** Payload describing a notification create request. */
    interface NotificationCreate {
        /** The version of the notification specification. */
        specversion: string;
        /** The time notification was created. */
        time?: string;
        /** The unique identifier of the notification. */
        id: string;
        /** The source of notifications. */
        source: string;
        /** The notifications type. */
        type: string;
        /** The severity of the notification. */
        ibmenseverity?: string;
        /** The source id of the notification. */
        ibmensourceid: string;
        /** Default short text for the message. */
        ibmendefaultshort: string;
        /** Default long text for the message. */
        ibmendefaultlong: string;
        /** The subject of the notification. */
        subject?: string;
        /** The payload for webhook notification. */
        data?: JsonObject;
        /** The notification content type. */
        datacontenttype?: string;
        /** If platforms or tags or user_ids is used then do not use fcm_devices / apns_devices / chrome_devices /
         *  firefox_devices / safari_devices with it. Value should be stringified.
         */
        ibmenpushto?: string;
        /** Payload describing a notification FCM body. Value should be stringified. */
        ibmenfcmbody?: string;
        /** Payload describing a notification APNs body. Value should be stringified. */
        ibmenapnsbody?: string;
        /** Headers for iOS notification. Value should be stringified. */
        ibmenapnsheaders?: string;
        /** Notification payload for Chrome. Value should be stringified. */
        ibmenchromebody?: string;
        /** Headers for a Chrome notification. Value should be stringified. */
        ibmenchromeheaders?: string;
        /** Notification payload for Firefox. Value should be stringified. */
        ibmenfirefoxbody?: string;
        /** Headers for a Firefox notification. Value should be stringified. */
        ibmenfirefoxheaders?: string;
        /** Payload describing a notification Safari body. Value should be stringified. */
        ibmensafaribody?: string;
        /** NotificationCreate accepts additional properties. */
        [propName: string]: any;
    }
    /** Payload describing a notifications response. */
    interface NotificationResponse {
        /** Notification ID. */
        notification_id?: string;
    }
    /** Response having URL of the page. */
    interface PageHrefResponse {
        /** URL to the page. */
        href: string;
    }
    /** Rule object. */
    interface Rules {
        /** Whether the rule is enabled or not. */
        enabled?: boolean;
        /** Event type filter. */
        event_type_filter: string;
        /** Notification filter. */
        notification_filter?: string;
    }
    /** Rule object. */
    interface RulesGet {
        /** Whether the rule is enabled or not. */
        enabled: boolean;
        /** Event type filter. */
        event_type_filter: string;
        /** Notification filter. */
        notification_filter: string;
        /** Last time the topic was updated. */
        updated_at: string;
        /** Autogenerated rule ID. */
        id: string;
    }
    /** The sms attributes. */
    interface SMSAttributesItems {
        /** Phone number. */
        phone_number?: string;
        /** last updated time. */
        updated_at?: string;
    }
    /** The sms attributes. */
    interface SMSInviteAttributesItems {
        /** Phone number. */
        phone_number?: string;
        /** last updated time. */
        updated_at?: string;
        /** time of expiration. */
        expires_at?: string;
    }
    /** Payload describing a source generate request. */
    interface Source {
        /** The id of the source. */
        id: string;
        /** The name of the source. */
        name: string;
        /** The description of the source. */
        description: string;
        /** The status of the source. */
        enabled: boolean;
        /** Type of the source. */
        type: string;
        /** The last updated time of the source. */
        updated_at: string;
        /** The number of topics. */
        topic_count: number;
        /** The names of the topics. */
        topic_names: string[];
    }
    /** Payload describing a source list request. */
    interface SourceList {
        /** Number of sources. */
        total_count: number;
        /** Current offset. */
        offset: number;
        /** limit to show sources. */
        limit: number;
        /** List of sources. */
        sources: SourceListItem[];
        /** Response having URL of the page. */
        first?: PageHrefResponse;
        /** Response having URL of the page. */
        previous?: PageHrefResponse;
        /** Response having URL of the page. */
        next?: PageHrefResponse;
    }
    /** Payload describing a source list item. */
    interface SourceListItem {
        /** ID of the source. */
        id: string;
        /** Name of the source. */
        name: string;
        /** Description of the source. */
        description: string;
        /** Type of the source. */
        type: string;
        /** Whether the source is enabled or not. */
        enabled: boolean;
        /** Time of the last update. */
        updated_at: string;
        /** Number of topics. */
        topic_count: number;
    }
    /** Payload describing a source. */
    interface SourceResponse {
        /** ID of the source. */
        id: string;
        /** Name of the source. */
        name: string;
        /** Description of the source. */
        description: string;
        /** Whether the source is enabled or not. */
        enabled: boolean;
        /** Time of the created. */
        created_at: string;
    }
    /** SourcesItems. */
    interface SourcesItems {
        /** ID of the source. */
        id: string;
        /** List of rules. */
        rules: Rules[];
    }
    /** Payload describing a source list item. */
    interface SourcesListItems {
        /** ID of the source. */
        id: string;
        /** Name of the source. */
        name: string;
        /** List of rules. */
        rules?: RulesGet[];
    }
    /** Subscription object. */
    interface Subscription {
        /** Subscription ID. */
        id: string;
        /** Subscription name. */
        name: string;
        /** Subscription description. */
        description: string;
        /** Last updated time. */
        updated_at: string;
        /** From Email ID (it will be displayed only in case of smtp_ibm destination type). */
        from?: string;
        /** The type of destination. */
        destination_type: string;
        /** The destination ID. */
        destination_id: string;
        /** The destination name. */
        destination_name: string;
        /** Topic ID. */
        topic_id: string;
        /** Topic name. */
        topic_name: string;
        attributes?: SubscriptionAttributes;
        /** Subscription accepts additional properties. */
        [propName: string]: any;
    }
    /** SubscriptionAttributes. */
    interface SubscriptionAttributes {
        /** SubscriptionAttributes accepts additional properties. */
        [propName: string]: any;
    }
    /** SubscriptionCreateAttributes. */
    interface SubscriptionCreateAttributes {
    }
    /** Subscription list object. */
    interface SubscriptionList {
        /** Number of subscriptions. */
        total_count: number;
        /** Current offset. */
        offset: number;
        /** limit to show subscriptions. */
        limit: number;
        /** List of subscriptions. */
        subscriptions: SubscriptionListItem[];
        /** Response having URL of the page. */
        first?: PageHrefResponse;
        /** Response having URL of the page. */
        previous?: PageHrefResponse;
        /** Response having URL of the page. */
        next?: PageHrefResponse;
    }
    /** Subscription list item. */
    interface SubscriptionListItem {
        /** ID of the subscription. */
        id: string;
        /** Name of the subscription. */
        name: string;
        /** Description of the subscription. */
        description: string;
        /** ID of the destination. */
        destination_id: string;
        /** Name of the destination. */
        destination_name?: string;
        /** The type of destination. */
        destination_type: string;
        /** ID of the topic. */
        topic_id: string;
        /** Name of the topic. */
        topic_name?: string;
        /** Last updated time of the subscription. */
        updated_at: string;
    }
    /** SubscriptionUpdateAttributes. */
    interface SubscriptionUpdateAttributes {
    }
    /** Payload describing a tags list request. */
    interface TagsSubscriptionList {
        /** Total number of tags. */
        total_count: number;
        /** Current offset. */
        offset: number;
        /** limit to show tags. */
        limit: number;
        /** List of tags. */
        tag_subscriptions: TagsSubscriptionListItem[];
        /** Response having URL of the page. */
        first?: PageHrefResponse;
        /** Response having URL of the page. */
        previous?: PageHrefResponse;
        /** Response having URL of the page. */
        next?: PageHrefResponse;
    }
    /** Tags subscription object. */
    interface TagsSubscriptionListItem {
        /** Subscription Tag ID. */
        id: string;
        /** Unique identifier of the device. */
        device_id: string;
        /** The name of the tag its subscribed. */
        tag_name: string;
        /** The user identifier for the device registration. */
        user_id?: string;
        /** Updated at. */
        updated_at: string;
    }
    /** Topic object. */
    interface Topic {
        /** Autogenerated topic ID. */
        id: string;
        /** Description of the topic. */
        description: string;
        /** Name of the topic. */
        name: string;
        /** Last time the topic was updated. */
        updated_at: string;
        /** Number of sources. */
        source_count: number;
        /** List of sources. */
        sources: SourcesListItems[];
        /** Number of subscriptions. */
        subscription_count: number;
        /** List of subscriptions. */
        subscriptions: SubscriptionListItem[];
    }
    /** Topic list object. */
    interface TopicList {
        /** Number of topics. */
        total_count: number;
        /** Current offset. */
        offset: number;
        /** limit to show subscriptions. */
        limit: number;
        /** List of topics. */
        topics: TopicsListItem[];
        /** Response having URL of the page. */
        first?: PageHrefResponse;
        /** Response having URL of the page. */
        previous?: PageHrefResponse;
        /** Response having URL of the page. */
        next?: PageHrefResponse;
    }
    /** Topic object. */
    interface TopicResponse {
        /** Autogenerated topic ID. */
        id: string;
        /** Name of the topic. */
        name: string;
        /** Description of the topic. */
        description: string;
        /** Last time the topic was updated. */
        created_at: string;
    }
    /** Topic list item object. */
    interface TopicsListItem {
        /** Autogenerated topic ID. */
        id: string;
        /** Name of the topic. */
        name: string;
        /** Description of the topic. */
        description: string;
        /** Number of sources. */
        source_count: number;
        /** List of source names. */
        sources_names: string[];
        /** Number of subscriptions. */
        subscription_count: number;
    }
    /** The email ids or phone numbers. */
    interface UpdateAttributesInvited {
        /** The email ids or phone numbers to be invited. */
        add?: string[];
        /** The email ids or phone numbers for removal. */
        remove?: string[];
    }
    /** The email ids or phone numbers. */
    interface UpdateAttributesSubscribed {
        /** The email ids or phone numbers to be unsubscribed. */
        remove?: string[];
    }
    /** The email ids or phone numbers. */
    interface UpdateAttributesUnsubscribed {
        /** The email ids or phone numbers to be unsubscribed. */
        remove?: string[];
    }
    /** Payload describing a Chrome destination configuration. */
    interface DestinationConfigOneOfChromeDestinationConfig extends DestinationConfigOneOf {
        /** FCM api_key. */
        api_key: string;
        /** Website url. */
        website_url: string;
        /** Chrome VAPID public key. */
        public_key?: string;
        /** If pre prod enabled. */
        pre_prod?: boolean;
    }
    /** Payload describing an FCM destination configuration. project_id, private_key and client_email for FCM HTTP v1 APIs. */
    interface DestinationConfigOneOfFCMDestinationConfig extends DestinationConfigOneOf {
        /** FCM server_key. */
        server_key?: string;
        /** FCM sender_id. */
        sender_id?: string;
        /** If pre prod enabled. */
        pre_prod?: boolean;
        /** FCM project_id. */
        project_id?: string;
        /** FCM private_key. */
        private_key?: string;
        /** FCM client_email. */
        client_email?: string;
    }
    /** Payload describing a Firefox destination configuration. */
    interface DestinationConfigOneOfFirefoxDestinationConfig extends DestinationConfigOneOf {
        /** Website url. */
        website_url: string;
        /** Chrome VAPID public key. */
        public_key?: string;
        /** If pre prod enabled. */
        pre_prod?: boolean;
    }
    /** Payload describing an IBM Cloud Functions destination configuration. */
    interface DestinationConfigOneOfIBMCloudFunctionsDestinationConfig extends DestinationConfigOneOf {
        /** URL of IBM Cloud Functions Trigger EndPoint. */
        url: string;
        /** API Key with access of IBM Cloud Functions IAM Namespace. */
        api_key?: string;
    }
    /** Payload describing an iOS destination configuration. */
    interface DestinationConfigOneOfIOSDestinationConfig extends DestinationConfigOneOf {
        /** Authentication type (p8 or p12). */
        cert_type: string;
        /** Sandbox mode for iOS destinations. */
        is_sandbox: boolean;
        /** Password for certificate (Required when cert_type is p12). */
        password?: string;
        /** Key ID for token (Required when cert_type is p8). */
        key_id?: string;
        /** Team ID for token (Required when cert_type is p8). */
        team_id?: string;
        /** Bundle ID for token (Required when cert_type is p8). */
        bundle_id?: string;
        /** If pre prod enabled. */
        pre_prod?: boolean;
    }
    /** Payload describing a MS Teams destination configuration. */
    interface DestinationConfigOneOfMSTeamsDestinationConfig extends DestinationConfigOneOf {
        /** URL of MS Teams Incoming Notifications. */
        url: string;
    }
    /** Payload describing a PagerDuty destination configuration. */
    interface DestinationConfigOneOfPagerDutyDestinationConfig extends DestinationConfigOneOf {
        /** API Key for the PagerDuty account. */
        api_key: string;
        /** Routing Key (Integration Key) for the team in PagerDuty account. */
        routing_key: string;
    }
    /** Payload describing a Safari destination configuration. */
    interface DestinationConfigOneOfSafariDestinationConfig extends DestinationConfigOneOf {
        /** Authentication type p12. */
        cert_type: string;
        /** Password for certificate (Required when cert_type is p12). */
        password: string;
        /** Website url. */
        website_url: string;
        /** Website url. */
        website_name: string;
        /** Website url. */
        url_format_string: string;
        /** Website url. */
        website_push_id: string;
        /** If pre prod enabled. */
        pre_prod?: boolean;
    }
    /** Payload describing a ServiceNow destination configuration. */
    interface DestinationConfigOneOfServiceNowDestinationConfig extends DestinationConfigOneOf {
        /** ClientID for the ServiceNow account oauth. */
        client_id: string;
        /** ClientSecret for the ServiceNow account oauth. */
        client_secret: string;
        /** Username for ServiceNow account REST API. */
        username: string;
        /** Password for ServiceNow account REST API. */
        password: string;
        /** Instance name for ServiceNow account. */
        instance_name: string;
    }
    /** Payload describing a Slack destination configuration. */
    interface DestinationConfigOneOfSlackDestinationConfig extends DestinationConfigOneOf {
        /** URL of Slack Incoming Notifications. */
        url: string;
    }
    /** Payload describing a webhook destination configuration. */
    interface DestinationConfigOneOfWebhookDestinationConfig extends DestinationConfigOneOf {
        /** URL of webhook. */
        url: string;
        /** HTTP method of webhook. */
        verb: string;
        /** Custom headers (Key-Value pair) for webhook call. */
        custom_headers?: JsonObject;
        /** List of sensitive headers from custom headers. */
        sensitive_headers?: string[];
    }
    /** The attributes reponse for an email destination. */
    interface SubscriptionAttributesEmailAttributesResponse extends SubscriptionAttributes {
        /** The email id string. */
        invited?: EmailAttributesResponseInvitedItems[];
        /** The unsubscribe list. */
        subscribed?: EmailAttributesResponseSubscribedUnsubscribedItems[];
        /** The subscribed list. */
        unsubscribed?: EmailAttributesResponseSubscribedUnsubscribedItems[];
        /** Whether to add the notification payload to the email. */
        add_notification_payload: boolean;
        /** The email address to reply to. */
        reply_to_mail: string;
        /** The email name to reply to. */
        reply_to_name: string;
        /** The email name of From. */
        from_name: string;
    }
    /** SMS attributes object. */
    interface SubscriptionAttributesSMSAttributesResponse extends SubscriptionAttributes {
        /** The subscribed list. */
        subscribed?: SMSAttributesItems[];
        /** The unsubscribe list. */
        unsubscribed?: SMSAttributesItems[];
        /** The email id string. */
        invited?: SMSInviteAttributesItems[];
    }
    /** The attributes for a ServiceNow notification. */
    interface SubscriptionAttributesServiceNowAttributesResponse extends SubscriptionAttributes {
        /** Assigned name from ServiceNow account. */
        assigned_to?: string;
        /** Assigned group name from ServiceNow account. */
        assignment_group?: string;
    }
    /** The attributes for a Slack notification. */
    interface SubscriptionAttributesSlackAttributesResponse extends SubscriptionAttributes {
        /** Attachment Color for Slack Notification. */
        attachment_color: string;
    }
    /** The attributes for a webhook notification. */
    interface SubscriptionAttributesWebhookAttributesResponse extends SubscriptionAttributes {
        /** Signing webhook attributes. */
        signing_enabled: boolean;
        /** Decision for Notification Payload to be added. */
        add_notification_payload: boolean;
    }
    /** The attributes for an email notification. */
    interface SubscriptionCreateAttributesEmailAttributes extends SubscriptionCreateAttributes {
        /** The email id string. */
        invited: string[];
        /** Whether to add the notification payload to the email. */
        add_notification_payload: boolean;
        /** The email address to reply to. */
        reply_to_mail: string;
        /** The email name to reply to. */
        reply_to_name: string;
        /** The email name of From. */
        from_name: string;
    }
    /** The attributes for an FCM notification. */
    interface SubscriptionCreateAttributesFCMAttributes extends SubscriptionCreateAttributes {
    }
    /** The attributes for an sms notification. */
    interface SubscriptionCreateAttributesSMSAttributes extends SubscriptionCreateAttributes {
        /** The sms id string. */
        invited: string[];
    }
    /** The attributes for a ServiceNow notification. */
    interface SubscriptionCreateAttributesServiceNowAttributes extends SubscriptionCreateAttributes {
        /** Name of user ServiceNow incident will be assigned to. */
        assigned_to?: string;
        /** Group Name to which incident will be assigned to. */
        assignment_group?: string;
    }
    /** The attributes for a slack notification. */
    interface SubscriptionCreateAttributesSlackAttributes extends SubscriptionCreateAttributes {
        /** Attachment Color for the slack message. */
        attachment_color: string;
    }
    /** The attributes for a webhook notification. */
    interface SubscriptionCreateAttributesWebhookAttributes extends SubscriptionCreateAttributes {
        /** Signing webhook attributes. */
        signing_enabled: boolean;
    }
    /** The attributes for an email notification. */
    interface SubscriptionUpdateAttributesEmailUpdateAttributes extends SubscriptionUpdateAttributes {
        /** The email ids or phone numbers. */
        invited?: UpdateAttributesInvited;
        /** Whether to add the notification payload to the email. */
        add_notification_payload: boolean;
        /** The email address to reply to. */
        reply_to_mail: string;
        /** The email name to reply to. */
        reply_to_name: string;
        /** The email name of From. */
        from_name: string;
        /** The email ids or phone numbers. */
        subscribed?: UpdateAttributesSubscribed;
        /** The email ids or phone numbers. */
        unsubscribed?: UpdateAttributesUnsubscribed;
    }
    /** SMS attributes object. */
    interface SubscriptionUpdateAttributesSMSUpdateAttributes extends SubscriptionUpdateAttributes {
        /** The email ids or phone numbers. */
        invited?: UpdateAttributesInvited;
        /** The email ids or phone numbers. */
        subscribed?: UpdateAttributesSubscribed;
        /** The email ids or phone numbers. */
        unsubscribed?: UpdateAttributesUnsubscribed;
    }
    /** The attributes for a ServiceNow notification. */
    interface SubscriptionUpdateAttributesServiceNowAttributes extends SubscriptionUpdateAttributes {
        /** Name of user ServiceNow incident will be assigned to. */
        assigned_to?: string;
        /** Group Name to which incident will be assigned to. */
        assignment_group?: string;
    }
    /** The attributes for a slack notification. */
    interface SubscriptionUpdateAttributesSlackAttributes extends SubscriptionUpdateAttributes {
        /** Attachment Color for the slack message. */
        attachment_color: string;
    }
    /** The attributes for a webhook notification. */
    interface SubscriptionUpdateAttributesWebhookAttributes extends SubscriptionUpdateAttributes {
        /** Signing webhook attributes. */
        signing_enabled: boolean;
    }
    /*************************
     * pager classes
     ************************/
    /**
     * SourcesPager can be used to simplify the use of listSources().
     */
    class SourcesPager {
        protected _hasNext: boolean;
        protected pageContext: any;
        protected client: EventNotificationsV1;
        protected params: EventNotificationsV1.ListSourcesParams;
        /**
         * Construct a SourcesPager object.
         *
         * @param {EventNotificationsV1}  client - The service client instance used to invoke listSources()
         * @param {Object} params - The parameters to be passed to listSources()
         * @constructor
         * @returns {SourcesPager}
         */
        constructor(client: EventNotificationsV1, params: EventNotificationsV1.ListSourcesParams);
        /**
         * Returns true if there are potentially more results to be retrieved by invoking getNext().
         * @returns {boolean}
         */
        hasNext(): boolean;
        /**
         * Returns the next page of results by invoking listSources().
         * @returns {Promise<EventNotificationsV1.SourceListItem[]>}
         */
        getNext(): Promise<EventNotificationsV1.SourceListItem[]>;
        /**
         * Returns all results by invoking listSources() repeatedly until all pages of results have been retrieved.
         * @returns {Promise<EventNotificationsV1.SourceListItem[]>}
         */
        getAll(): Promise<EventNotificationsV1.SourceListItem[]>;
    }
    /**
     * TopicsPager can be used to simplify the use of listTopics().
     */
    class TopicsPager {
        protected _hasNext: boolean;
        protected pageContext: any;
        protected client: EventNotificationsV1;
        protected params: EventNotificationsV1.ListTopicsParams;
        /**
         * Construct a TopicsPager object.
         *
         * @param {EventNotificationsV1}  client - The service client instance used to invoke listTopics()
         * @param {Object} params - The parameters to be passed to listTopics()
         * @constructor
         * @returns {TopicsPager}
         */
        constructor(client: EventNotificationsV1, params: EventNotificationsV1.ListTopicsParams);
        /**
         * Returns true if there are potentially more results to be retrieved by invoking getNext().
         * @returns {boolean}
         */
        hasNext(): boolean;
        /**
         * Returns the next page of results by invoking listTopics().
         * @returns {Promise<EventNotificationsV1.TopicsListItem[]>}
         */
        getNext(): Promise<EventNotificationsV1.TopicsListItem[]>;
        /**
         * Returns all results by invoking listTopics() repeatedly until all pages of results have been retrieved.
         * @returns {Promise<EventNotificationsV1.TopicsListItem[]>}
         */
        getAll(): Promise<EventNotificationsV1.TopicsListItem[]>;
    }
    /**
     * DestinationsPager can be used to simplify the use of listDestinations().
     */
    class DestinationsPager {
        protected _hasNext: boolean;
        protected pageContext: any;
        protected client: EventNotificationsV1;
        protected params: EventNotificationsV1.ListDestinationsParams;
        /**
         * Construct a DestinationsPager object.
         *
         * @param {EventNotificationsV1}  client - The service client instance used to invoke listDestinations()
         * @param {Object} params - The parameters to be passed to listDestinations()
         * @constructor
         * @returns {DestinationsPager}
         */
        constructor(client: EventNotificationsV1, params: EventNotificationsV1.ListDestinationsParams);
        /**
         * Returns true if there are potentially more results to be retrieved by invoking getNext().
         * @returns {boolean}
         */
        hasNext(): boolean;
        /**
         * Returns the next page of results by invoking listDestinations().
         * @returns {Promise<EventNotificationsV1.DestinationListItem[]>}
         */
        getNext(): Promise<EventNotificationsV1.DestinationListItem[]>;
        /**
         * Returns all results by invoking listDestinations() repeatedly until all pages of results have been retrieved.
         * @returns {Promise<EventNotificationsV1.DestinationListItem[]>}
         */
        getAll(): Promise<EventNotificationsV1.DestinationListItem[]>;
    }
    /**
     * TagsSubscriptionPager can be used to simplify the use of listTagsSubscription().
     */
    class TagsSubscriptionPager {
        protected _hasNext: boolean;
        protected pageContext: any;
        protected client: EventNotificationsV1;
        protected params: EventNotificationsV1.ListTagsSubscriptionParams;
        /**
         * Construct a TagsSubscriptionPager object.
         *
         * @param {EventNotificationsV1}  client - The service client instance used to invoke listTagsSubscription()
         * @param {Object} params - The parameters to be passed to listTagsSubscription()
         * @constructor
         * @returns {TagsSubscriptionPager}
         */
        constructor(client: EventNotificationsV1, params: EventNotificationsV1.ListTagsSubscriptionParams);
        /**
         * Returns true if there are potentially more results to be retrieved by invoking getNext().
         * @returns {boolean}
         */
        hasNext(): boolean;
        /**
         * Returns the next page of results by invoking listTagsSubscription().
         * @returns {Promise<EventNotificationsV1.TagsSubscriptionListItem[]>}
         */
        getNext(): Promise<EventNotificationsV1.TagsSubscriptionListItem[]>;
        /**
         * Returns all results by invoking listTagsSubscription() repeatedly until all pages of results have been retrieved.
         * @returns {Promise<EventNotificationsV1.TagsSubscriptionListItem[]>}
         */
        getAll(): Promise<EventNotificationsV1.TagsSubscriptionListItem[]>;
    }
    /**
     * SubscriptionsPager can be used to simplify the use of listSubscriptions().
     */
    class SubscriptionsPager {
        protected _hasNext: boolean;
        protected pageContext: any;
        protected client: EventNotificationsV1;
        protected params: EventNotificationsV1.ListSubscriptionsParams;
        /**
         * Construct a SubscriptionsPager object.
         *
         * @param {EventNotificationsV1}  client - The service client instance used to invoke listSubscriptions()
         * @param {Object} params - The parameters to be passed to listSubscriptions()
         * @constructor
         * @returns {SubscriptionsPager}
         */
        constructor(client: EventNotificationsV1, params: EventNotificationsV1.ListSubscriptionsParams);
        /**
         * Returns true if there are potentially more results to be retrieved by invoking getNext().
         * @returns {boolean}
         */
        hasNext(): boolean;
        /**
         * Returns the next page of results by invoking listSubscriptions().
         * @returns {Promise<EventNotificationsV1.SubscriptionListItem[]>}
         */
        getNext(): Promise<EventNotificationsV1.SubscriptionListItem[]>;
        /**
         * Returns all results by invoking listSubscriptions() repeatedly until all pages of results have been retrieved.
         * @returns {Promise<EventNotificationsV1.SubscriptionListItem[]>}
         */
        getAll(): Promise<EventNotificationsV1.SubscriptionListItem[]>;
    }
    /**
     * IntegrationsPager can be used to simplify the use of listIntegrations().
     */
    class IntegrationsPager {
        protected _hasNext: boolean;
        protected pageContext: any;
        protected client: EventNotificationsV1;
        protected params: EventNotificationsV1.ListIntegrationsParams;
        /**
         * Construct a IntegrationsPager object.
         *
         * @param {EventNotificationsV1}  client - The service client instance used to invoke listIntegrations()
         * @param {Object} params - The parameters to be passed to listIntegrations()
         * @constructor
         * @returns {IntegrationsPager}
         */
        constructor(client: EventNotificationsV1, params: EventNotificationsV1.ListIntegrationsParams);
        /**
         * Returns true if there are potentially more results to be retrieved by invoking getNext().
         * @returns {boolean}
         */
        hasNext(): boolean;
        /**
         * Returns the next page of results by invoking listIntegrations().
         * @returns {Promise<EventNotificationsV1.IntegrationListItem[]>}
         */
        getNext(): Promise<EventNotificationsV1.IntegrationListItem[]>;
        /**
         * Returns all results by invoking listIntegrations() repeatedly until all pages of results have been retrieved.
         * @returns {Promise<EventNotificationsV1.IntegrationListItem[]>}
         */
        getAll(): Promise<EventNotificationsV1.IntegrationListItem[]>;
    }
}
export = EventNotificationsV1;
